@@ -166,10 +166,13 @@ class TraceProcessor(Thread):
             module = inspect.getmodule(code)
             if module:
                 module_name = module.__name__
-                module_path = module.__file__
+                try:
+                    module_path = module.__file__
 
-                if not self.config.include_stdlib \
-                        and self.is_module_stdlib(module_path):
+                    if not self.config.include_stdlib \
+                            and self.is_module_stdlib(module_path):
+                        keep = False
+                except AttributeError:
                     keep = False
 
                 if module_name == '__main__':
